# python-structures
[![Build Status](https://travis-ci.org/pedroteosousa/python-structures.svg?branch=master)](https://travis-ci.org/pedroteosousa/python-structures)

Implementations of data structures in python

## License
This project is licensed under the MIT License